@@ -65,7 +65,7 @@ def heading(content, carryForward=None):
     text=""
     for c in content:
         text += parse(c)
-    return text+"\n"
+    return text+" \n"
 
 #Child Level
 def listItem(content, carryForward):
@@ -123,11 +123,14 @@ def parse(adf, carryForward=None, debug=False):
         "mention": (mention, 'attrs'),                          #Available only with type="text"
         "emoji": (emoji, 'attrs')
     }
+    replacers = ["\n\n\n\n", "\n\n\n", "\n\n"]
     type=switcher.get(adf['type'])                              #Get the ADF Type | Ex: "paragraph"
     fn=type[0]                                                  #Get the Function | Ex: paragraph()
     data=adf if type[1]=="self" else adf.get(type[1], None)     #Get the data to parse | Ex: "content" or "attrs" or "text"
     try: 
         result=fn(data, carryForward)                           #Ex: listItem(adf["content"], 1)
+        for r in replacers:        
+            result=result.replace(r, '\n')
         enablePrint()
         return result
     except: 
